package com.aucma.base.service.impl;

import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseSpaceInfoMapper;
import com.aucma.base.domain.BaseSpaceInfo;
import com.aucma.base.service.IBaseSpaceInfoService;

/**
 * 货道信息Service业务层处理
 * 
 * @author Yinq
 * @date 2023-09-20
 */
@Service
public class BaseSpaceInfoServiceImpl implements IBaseSpaceInfoService 
{
    @Autowired
    private BaseSpaceInfoMapper baseSpaceInfoMapper;

    /**
     * 查询货道信息
     * 
     * @param objId 货道信息主键
     * @return 货道信息
     */
    @Override
    public BaseSpaceInfo selectBaseSpaceInfoByObjId(Long objId)
    {
        return baseSpaceInfoMapper.selectBaseSpaceInfoByObjId(objId);
    }

    /**
     * 查询货道信息列表
     * 
     * @param baseSpaceInfo 货道信息
     * @return 货道信息
     */
    @Override
    public List<BaseSpaceInfo> selectBaseSpaceInfoList(BaseSpaceInfo baseSpaceInfo)
    {
        return baseSpaceInfoMapper.selectBaseSpaceInfoList(baseSpaceInfo);
    }

    /**
     * 新增货道信息
     * 
     * @param baseSpaceInfo 货道信息
     * @return 结果
     */
    @Override
    public int insertBaseSpaceInfo(BaseSpaceInfo baseSpaceInfo)
    {
        return baseSpaceInfoMapper.insertBaseSpaceInfo(baseSpaceInfo);
    }

    /**
     * 修改货道信息
     * 
     * @param baseSpaceInfo 货道信息
     * @return 结果
     */
    @Override
    public int updateBaseSpaceInfo(BaseSpaceInfo baseSpaceInfo)
    {
        return baseSpaceInfoMapper.updateBaseSpaceInfo(baseSpaceInfo);
    }

    /**
     * 批量删除货道信息
     * 
     * @param objIds 需要删除的货道信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseSpaceInfoByObjIds(Long[] objIds)
    {
        return baseSpaceInfoMapper.deleteBaseSpaceInfoByObjIds(objIds);
    }

    /**
     * 删除货道信息信息
     * 
     * @param objId 货道信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseSpaceInfoByObjId(Long objId)
    {
        return baseSpaceInfoMapper.deleteBaseSpaceInfoByObjId(objId);
    }


    /**
     * 库存统计
     * @param baseSpaceInfo
     * @return
     */
    @Override
    public List<LinkedHashMap<String,String>> getInventoryStatistics(BaseSpaceInfo baseSpaceInfo) {
        return baseSpaceInfoMapper.getInventoryStatistics(baseSpaceInfo);
    }


}
