package com.aucma.base.controller;

import java.util.LinkedHashMap;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.BaseSpaceInfo;
import com.aucma.base.service.IBaseSpaceInfoService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 货道信息Controller
 *
 * @author Yinq
 * @date 2023-09-20
 */
@RestController
@RequestMapping("/base/spaceInfo" )
public class BaseSpaceInfoController extends BaseController {
    @Autowired
    private IBaseSpaceInfoService baseSpaceInfoService;

    /**
     * 查询货道信息列表
     */
    @PreAuthorize("@ss.hasPermi('base:spaceInfo:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(BaseSpaceInfo baseSpaceInfo) {
        startPage();
        List<BaseSpaceInfo> list = baseSpaceInfoService.selectBaseSpaceInfoList(baseSpaceInfo);
        return getDataTable(list);
    }

    /**
     * 不分页查询货道信息列表
     * @param baseSpaceInfo
     * @return
     */
    @GetMapping("/spaceList" )
    public AjaxResult spaceList(BaseSpaceInfo baseSpaceInfo) {
        List<BaseSpaceInfo> list = baseSpaceInfoService.selectBaseSpaceInfoList(baseSpaceInfo);
        return success(list);
    }

    /**
     * 导出货道信息列表
     */
    @PreAuthorize("@ss.hasPermi('base:spaceInfo:export')" )
    @Log(title = "货道信息" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, BaseSpaceInfo baseSpaceInfo) {
        List<BaseSpaceInfo> list = baseSpaceInfoService.selectBaseSpaceInfoList(baseSpaceInfo);
        ExcelUtil<BaseSpaceInfo> util = new ExcelUtil<BaseSpaceInfo>(BaseSpaceInfo. class);
        util.exportExcel(response, list, "货道信息数据" );
    }

    /**
     * 获取货道信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:spaceInfo:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(baseSpaceInfoService.selectBaseSpaceInfoByObjId(objId));
    }

    /**
     * 新增货道信息
     */
    @PreAuthorize("@ss.hasPermi('base:spaceInfo:add')" )
    @Log(title = "货道信息" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseSpaceInfo baseSpaceInfo) {
        baseSpaceInfo.setCreatedBy(getUsername());
        baseSpaceInfo.setCreatedTime(DateUtils.getNowDate());
        return toAjax(baseSpaceInfoService.insertBaseSpaceInfo(baseSpaceInfo));
    }

    /**
     * 修改货道信息
     */
    @PreAuthorize("@ss.hasPermi('base:spaceInfo:edit')" )
    @Log(title = "货道信息" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseSpaceInfo baseSpaceInfo) {
        baseSpaceInfo.setUpdatedBy(getUsername());
        baseSpaceInfo.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(baseSpaceInfoService.updateBaseSpaceInfo(baseSpaceInfo));
    }

    /**
     * 删除货道信息
     */
    @PreAuthorize("@ss.hasPermi('base:spaceInfo:remove')" )
    @Log(title = "货道信息" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(baseSpaceInfoService.deleteBaseSpaceInfoByObjIds(objIds));
    }

    /**
     * 库存统计
     * @param baseSpaceInfo
     * @return
     */
    @GetMapping("/getInventoryStatistics" )
    public AjaxResult getInventoryStatistics(BaseSpaceInfo baseSpaceInfo) {
        List<LinkedHashMap<String,String>> list = baseSpaceInfoService.getInventoryStatistics(baseSpaceInfo);
        return success(list);
    }

}
